#!/bin/sh
# The following URLS are the 10.0.2 idle-time check urls from
# https://wiki.mozilla.org/Release:Release_Automation_on_Mercurial:Updates_through_Shipping#Verifying_Throttling
#
# URLS:
#   https://aus3.mozilla.org/update/1/Firefox/10.0.2/20120215223356/WINNT_x86-msvc/en-US/release/update.xml
#   https://aus3.mozilla.org/update/1/Firefox/10.0.2/20120215223356/Darwin_x86_64-gcc3-u-i386-x86_64/en-US/release/update.xml
#   https://aus3.mozilla.org/update/1/Firefox/10.0.2/20120215223356/Linux_x86-gcc3/en-US/release/update.xml
#   https://aus3.mozilla.org/update/1/Firefox/10.0.2/20120215223356/Linux_x86_64-gcc3/en-US/release/update.xml
#
# To test use the following syntax in a terminal prompt, where %URL% is one of the above URLs:
#   ./throttle.sh URL
#
# This should be something large if we're testing to see if we're partially throttled.
# It doesn't have to be huge if we're testing fully throttled or not throttled at all.
URL=$1
NUM_CHECKS=1000
THROTTLE=0
count=0
attempt=0
percent=0
while [ $attempt -lt $NUM_CHECKS ] ; do
  curl -s "$URL?x=$RANDOM" | grep -q hashValue
  if [ $? -eq 0 ] ; then
    count=`expr $count + 1`
  fi
  percent=`expr $attempt \* 100 / $NUM_CHECKS`
  attempt=`expr $attempt + 1`
  clear
  echo "Checking $URL"
  echo "Please wait, this will take several minutes...\n"
  echo "Successful background update pings: $count / $attempt ($percent% complete)"
done
THROTTLE=`expr $count \* 100 / $attempt`
echo "$URL: $THROTTLE% throttled.\n"